pub struct Style { /* private fields */ }Expand description
ANSI Text styling
You can print a Style to render the corresponding ANSI code.
Using the alternate flag # will render the ANSI reset code, if needed.
Together, this makes it convenient to render styles using inline format arguments.
Examples
let style = anstyle::Style::new().bold();
let value = 42;
println!("{style}{value}{style:#}");Implementations
Sourceimpl Style
Core
impl Style
Core
Sourcepub const fn fg_color(self, fg: Option<Color>) -> Style
pub const fn fg_color(self, fg: Option<Color>) -> Style
Set foreground color
Examples
let style = anstyle::Style::new().fg_color(Some(anstyle::AnsiColor::Red.into()));Sourcepub const fn bg_color(self, bg: Option<Color>) -> Style
pub const fn bg_color(self, bg: Option<Color>) -> Style
Set background color
Examples
let style = anstyle::Style::new().bg_color(Some(anstyle::AnsiColor::Red.into()));Sourcepub const fn underline_color(self, underline: Option<Color>) -> Style
pub const fn underline_color(self, underline: Option<Color>) -> Style
Set underline color
Examples
let style = anstyle::Style::new().underline_color(Some(anstyle::AnsiColor::Red.into()));Sourcepub const fn effects(self, effects: Effects) -> Style
pub const fn effects(self, effects: Effects) -> Style
Set text effects
Examples
let style = anstyle::Style::new().effects(anstyle::Effects::BOLD | anstyle::Effects::UNDERLINE);Sourcepub fn render(self) -> impl Display + Copy
pub fn render(self) -> impl Display + Copy
Render the ANSI code
Style also implements Display directly, so calling this method is optional.
Sourcepub fn render_reset(self) -> impl Display + Copy
pub fn render_reset(self) -> impl Display + Copy
Renders the relevant Reset code
Unlike Reset::render, this will elide the code if there is nothing to reset.
Sourcepub fn write_reset_to(self, write: &mut dyn Write) -> Result<(), Error>
pub fn write_reset_to(self, write: &mut dyn Write) -> Result<(), Error>
Write the relevant Reset code
Unlike Reset::render, this will elide the code if there is nothing to reset.
Sourceimpl Style
Convenience
impl Style
Convenience
Sourceimpl Style
Reflection
impl Style
Reflection
Sourcepub const fn get_fg_color(self) -> Option<Color>
pub const fn get_fg_color(self) -> Option<Color>
Get the foreground color
Sourcepub const fn get_bg_color(self) -> Option<Color>
pub const fn get_bg_color(self) -> Option<Color>
Get the background color
pub const fn get_underline_color(self) -> Option<Color>
pub const fn get_effects(self) -> Effects